@@ -133,7 +133,8 @@ bool Application::OnInit()
     //                  drawback: missing MTP and network links in folder picker: https://freefilesync.org/forum/viewtopic.php?t=6871
     //if (::setenv("GIO_USE_VFS", "local", true /*overwrite*/) != 0)
     //    std::cerr << utfTo<std::string>(formatSystemError("setenv(GIO_USE_VFS)", errno)) + '\n';
-    //
+    //    //BUGZ!?: "Modifications of environment variables are not allowed in multi-threaded programs" - https://rachelbythebay.com/w/2017/01/30/env/
+
     //=> work around 2:
     [[maybe_unused]] GVfs* defaultFs = ::g_vfs_get_default(); //not owned by us!
     //no such issue on GTK3!
@@ -242,26 +243,16 @@ wxLayoutDirection Application::GetLayoutDirection() const { return getLayoutDire
 
 int Application::OnRun()
 {
-    [[maybe_unused]] const int rc = wxApp::OnRun();
+#if wxUSE_EXCEPTIONS
+#error why is wxWidgets uncaught exception handling enabled!?
+#endif
+
+    //exception => Windows: let it crash and create mini dump!!! Linux/macOS: std::exception::what() logged to console
+        [[maybe_unused]] const int rc = wxApp::OnRun();
     return static_cast<int>(exitCode_);
 }
 
 
-void Application::OnUnhandledException() //handles both wxApp::OnInit() + wxApp::OnRun()
-{
-    try
-    {
-        throw; //just re-throw
-    }
-    catch (const std::bad_alloc& e) //the only kind of exception we don't want crash dumps for
-    {
-        notifyAppError(utfTo<std::wstring>(e.what()));
-        terminateProcess(static_cast<int>(FfsExitCode::exception));
-    }
-    //catch (...) -> Windows: let it crash and create mini dump!!! Linux/macOS: std::exception::what() logged to console
-}
-
-
 
 
 void Application::onEnterEventLoop()
@@ -418,7 +409,7 @@ void Application::onEnterEventLoop()
             else
             {
                 XmlGuiConfig guiCfg;
-                guiCfg.mainCfg.syncCfg.directionCfg.var = SyncVariant::mirror;
+                guiCfg.mainCfg.syncCfg.directionCfg = getDefaultSyncCfg(SyncVariant::mirror);
 
                 replaceDirectories(guiCfg.mainCfg); //throw FileError
 
@@ -626,9 +617,9 @@ void Application::runBatchMode(const Zstring& globalConfigFilePath, const XmlBat
 
     if (statusHandler.taskCancelled() && *statusHandler.taskCancelled() == CancelReason::user)
         ; /* user cancelled => don't run post sync command
+                            => don't run post sync action
                             => don't send email notification
-                            => don't play sound notification
-                            => don't run post sync action     */
+                            => don't play sound notification  */
     else
     {
         //--------------------- post sync command ----------------------
