@@ -22,8 +22,6 @@ private:
     bool OnInit() override;
     int  OnRun () override;
     int  OnExit() override;
-    bool OnExceptionInMainLoop() override { throw; } //just re-throw and avoid display of additional messagebox: it will be caught in OnUnhandledException()
-    void OnUnhandledException () override;
     wxLayoutDirection GetLayoutDirection() const override;
     void onEnterEventLoop();
 
