@@ -27,7 +27,7 @@ enum class BatchErrorHandling
 };
 
 
-enum class PostSyncAction
+enum class PostBatchAction
 {
     none,
     sleep,
@@ -47,7 +47,7 @@ extern const ExternalApp extCommandOpenDefault;
 struct XmlGuiConfig
 {
     MainConfiguration mainCfg;
-    GridViewType gridViewType = GridViewType::action;
+    GridViewType gridViewType = GridViewType::action; //keep "visual" setting out of "MainConfiguration"
 
     bool operator==(const XmlGuiConfig&) const = default;
 };
@@ -55,16 +55,16 @@ struct XmlGuiConfig
 
 struct BatchExclusiveConfig
 {
-    BatchErrorHandling batchErrorHandling = BatchErrorHandling::showPopup;
     bool runMinimized = false;
     bool autoCloseSummary = false;
-    PostSyncAction postSyncAction = PostSyncAction::none;
+    BatchErrorHandling batchErrorHandling = BatchErrorHandling::showPopup;
+    PostBatchAction postBatchAction = PostBatchAction::none;
 };
 
 
 struct XmlBatchConfig
 {
-    MainConfiguration mainCfg;
+    XmlGuiConfig guiCfg; //batch config can be used in GUI (but not the other way round)
     BatchExclusiveConfig batchExCfg;
 };
 
@@ -118,22 +118,24 @@ struct DpiLayout
 {
     struct
     {
-        wxPoint dlgPos;
-        wxSize dlgSize;
+        std::optional<wxSize> size;
+        std::optional<wxPoint> pos;
         bool isMaximized = false;
-        wxString panelLayout; //for wxAuiManager::LoadPerspective
-    } mainDlg;
+    } mainDlg; //WindowLayout::getBeforeClose()
+
+    struct
+    {
+        std::optional<wxSize> size;
+        //std::optional<wxPoint> pos; -> most users probably want it centered, but others at a fixed (relative??) location
+        bool isMaximized = false;
+    } progressDlg;
+
+    wxString panelLayout; //for wxAuiManager::LoadPerspective
 
     std::vector<ColAttributesCfg> configColumnAttribs = getCfgGridDefaultColAttribs();
     std::vector<ColumnAttribOverview> overviewColumnAttribs = getOverviewDefaultColAttribs();
     std::vector<ColAttributesRim> fileColumnAttribsLeft  = getFileGridDefaultColAttribsLeft();
     std::vector<ColAttributesRim> fileColumnAttribsRight = getFileGridDefaultColAttribsRight();
-
-    struct
-    {
-        wxSize dlgSize;
-        bool isMaximized = false;
-    } progressDlg;
 };
 
 
@@ -246,7 +248,7 @@ struct XmlGlobalSettings
     time_t lastUpdateCheck = 0; //number of seconds since Jan 1, 1970 GMT
     std::string lastOnlineVersion;
 
-    std::string welcomeShownVersion; //last FFS version for which the welcome dialog was shown
+    std::string welcomeDialogLastVersion;
 
     std::unordered_map<int /*scale percent*/, DpiLayout> dpiLayouts;
 };
@@ -263,15 +265,15 @@ void writeConfig(const XmlGlobalSettings& cfg, const Zstring& filePath); //
 //convert (multiple) *.ffs_gui, *.ffs_batch files or combinations of both into target config structure:
 std::pair<XmlGuiConfig, std::wstring /*warningMsg*/> readAnyConfig(const std::vector<Zstring>& filePaths); //throw FileError
 
-//config conversion utilities
-XmlGuiConfig   convertBatchToGui(const XmlBatchConfig& batchCfg); //noexcept
-XmlBatchConfig convertGuiToBatch(const XmlGuiConfig&   guiCfg, const BatchExclusiveConfig& batchExCfg); //
 
 std::wstring extractJobName(const Zstring& cfgFilePath);
 
 //human-readable/editable format suitable for clipboard
 std::string serializeFilter(const FilterConfig& filterCfg);
 std::optional<FilterConfig> parseFilterBuf(const std::string& filterBuf);
+
+void saveErrorLog(const zen::ErrorLog& log, const Zstring& filePath); //throw FileError
+zen::ErrorLog loadErrorLog(const Zstring& filePath); //throw FileError
 }
 
 #endif //PROCESS_XML_H_28345825704254262435
