@@ -6,7 +6,6 @@
 
 #include "batch_config.h"
 #include <wx/wupdlock.h>
-//#include <wx+/std_button_layout.h>
 #include <wx+/window_layout.h>
 #include <wx+/image_resources.h>
 #include <wx+/image_tools.h>
@@ -68,7 +67,7 @@ BatchDialog::BatchDialog(wxWindow* parent, BatchDialogConfig& dlgCfg) :
     setStandardButtonLayout(*bSizerStdButtons, StdButtons().setAffirmative(m_buttonSaveAs).setCancel(m_buttonCancel));
 
     m_staticTextHeader->SetLabelText(replaceCpy(m_staticTextHeader->GetLabelText(), L"%x", L"FreeFileSync.exe <" + _("configuration file") + L">.ffs_batch"));
-    m_staticTextHeader->Wrap(fastFromDIP(520));
+    m_staticTextHeader->Wrap(dipToWxsize(520));
 
     setImage(*m_bitmapBatchJob, loadImage("cfg_batch"));
 
