@@ -162,8 +162,7 @@ private:
 
     void onDialogFilesDropped(zen::FileDropEvent& event);
 
-    void onDirSelected(wxCommandEvent& event);
-    void onDirManualCorrection(wxCommandEvent& event);
+    void onFolderSelected(wxCommandEvent& event);
 
     void onCheckRows       (CheckRowsEvent&     event);
     void onSetSyncDirection(SyncDirectionEvent& event);
@@ -237,9 +236,6 @@ private:
     void setLastOperationLog(const ProcessSummary& summary, const std::shared_ptr<const zen::ErrorLog>& errorLog);
     void showLogPanel(bool show);
 
-    void filterExtension(const Zstring& extension, bool include);
-    void filterShortname(const FileSystemObject& fsObj, bool include);
-    void filterItems(const std::vector<FileSystemObject*>& selection, bool include);
     void addFilterPhrase(const Zstring& phrase, bool include, bool requireNewLine);
 
     void onTopFolderPairAdd   (wxCommandEvent& event) override;
@@ -277,7 +273,6 @@ private:
     void onMenuResetLayout    (wxCommandEvent& event) override { resetLayout(); }
     void onMenuFindItem       (wxCommandEvent& event) override { showFindPanel(true /*show*/); } //CTRL + F
     void onMenuCheckVersion   (wxCommandEvent& event) override;
-    void onMenuCheckVersionAutomatically(wxCommandEvent& event) override;
     void onMenuAbout          (wxCommandEvent& event) override;
     void onShowHelp           (wxCommandEvent& event) override { wxLaunchDefaultBrowser(L"https://freefilesync.org/manual.php?topic=freefilesync"); }
     void onMenuQuit           (wxCommandEvent& event) override { Close(); }
