@@ -32,7 +32,7 @@ namespace std
 //W(hy)TF is this not standard? https://stackoverflow.com/a/47735624
 template <class Char, class Traits, class Alloc> inline
 basic_string<Char, Traits, Alloc> operator+(basic_string<Char, Traits, Alloc>&& lhs, const basic_string_view<Char> rhs)
-{ return move(lhs.append(rhs.begin(), rhs.end())); } //the move *is* needed!!!
+{ return std::move(lhs.append(rhs.begin(), rhs.end())); } //the move *is* needed!!!
 
 //template <class Char> inline
 //basic_string<Char> operator+(const basic_string<Char>& lhs, const basic_string_view<Char>& rhs) { return basic_string<Char>(lhs) + rhs; }
