@@ -7,27 +7,24 @@
 #ifndef RESOLVE_PATH_H_817402834713454
 #define RESOLVE_PATH_H_817402834713454
 
-#include <vector>
-#include "zstring.h"
+#include "file_error.h"
 
 
 namespace zen
 {
-/*
-    - expand macros
+/*  - expand macros
     - trim whitespace
     - expand volume path by name
     - convert relative paths into absolute
 
-    => may block for slow USB sticks and idle HDDs
-    => not thread-safe, see ::GetFullPathName()!
-*/
+    => may block for slow USB sticks and idle HDDs     */
 Zstring getResolvedFilePath(const Zstring& pathPhrase); //noexcept
 
 //macro substitution only
 Zstring expandMacros(const Zstring& text);
 
-std::vector<Zstring> getFolderPathAliases(const Zstring& folderPathPhrase); //may block for slow USB sticks when resolving [<volume name>]
+std::vector<Zstring> getPathPhraseAliases(const Zstring& itemPath);
+Zstring makePathPhrase(const Zstring& itemPath);
 
 }
 
