@@ -19,11 +19,46 @@ namespace zen
     do { const ErrorCode ecInternal = getLastError(); throw SysError(formatSystemError(functionName, ecInternal)); } while (false)
 
 
+#define THROW_LAST_SYS_ERROR_GAI(rcGai)                        \
+    do {                                                       \
+        if (rcGai == EAI_SYSTEM) /*"check errno for details"*/ \
+            THROW_LAST_SYS_ERROR("getaddrinfo");               \
+        \
+        throw SysError(formatSystemError("getaddrinfo", formatGaiErrorCode(rcGai), utfTo<std::wstring>(::gai_strerror(rcGai)))); \
+    } while (false)
+
+inline
+std::wstring formatGaiErrorCode(int ec)
+{
+    switch (ec) //codes used on both Linux and macOS
+    {
+            ZEN_CHECK_CASE_FOR_CONSTANT(EAI_ADDRFAMILY);
+            ZEN_CHECK_CASE_FOR_CONSTANT(EAI_AGAIN);
+            ZEN_CHECK_CASE_FOR_CONSTANT(EAI_BADFLAGS);
+            ZEN_CHECK_CASE_FOR_CONSTANT(EAI_FAIL);
+            ZEN_CHECK_CASE_FOR_CONSTANT(EAI_FAMILY);
+            ZEN_CHECK_CASE_FOR_CONSTANT(EAI_MEMORY);
+            ZEN_CHECK_CASE_FOR_CONSTANT(EAI_NODATA);
+            ZEN_CHECK_CASE_FOR_CONSTANT(EAI_NONAME);
+            ZEN_CHECK_CASE_FOR_CONSTANT(EAI_SERVICE);
+            ZEN_CHECK_CASE_FOR_CONSTANT(EAI_SOCKTYPE);
+            ZEN_CHECK_CASE_FOR_CONSTANT(EAI_SYSTEM);
+            ZEN_CHECK_CASE_FOR_CONSTANT(EAI_OVERFLOW);
+            ZEN_CHECK_CASE_FOR_CONSTANT(EAI_INPROGRESS);
+            ZEN_CHECK_CASE_FOR_CONSTANT(EAI_CANCELED);
+            ZEN_CHECK_CASE_FOR_CONSTANT(EAI_NOTCANCELED);
+            ZEN_CHECK_CASE_FOR_CONSTANT(EAI_ALLDONE);
+            ZEN_CHECK_CASE_FOR_CONSTANT(EAI_INTR);
+            ZEN_CHECK_CASE_FOR_CONSTANT(EAI_IDN_ENCODE);
+        default:
+            return replaceCpy(_("Error code %x"), L"%x", numberTo<std::wstring>(ec));
+    }
+}
+
 //patch up socket portability:
 using SocketType = int;
 const SocketType invalidSocket = -1;
 inline void closeSocket(SocketType s) { ::close(s); }
-warn_static("log on error!")
 
 void setNonBlocking(SocketType socket, bool value); //throw SysError
 
@@ -53,7 +88,7 @@ public:
 
         const int rcGai = ::getaddrinfo(server.c_str(), serviceName.c_str(), &hints, &servinfo);
         if (rcGai != 0)
-            throw SysError(formatSystemError("getaddrinfo", replaceCpy(_("Error code %x"), L"%x", numberTo<std::wstring>(rcGai)), utfTo<std::wstring>(::gai_strerror(rcGai))));
+            THROW_LAST_SYS_ERROR_GAI(rcGai);
         if (!servinfo)
             throw SysError(formatSystemError("getaddrinfo", L"", L"Empty server info."));
 
@@ -143,7 +178,7 @@ namespace
 size_t tryReadSocket(SocketType socket, void* buffer, size_t bytesToRead) //throw SysError; may return short, only 0 means EOF!
 {
     if (bytesToRead == 0) //"read() with a count of 0 returns zero" => indistinguishable from end of file! => check!
-        throw std::logic_error("Contract violation! " + std::string(__FILE__) + ':' + numberTo<std::string>(__LINE__));
+        throw std::logic_error(std::string(__FILE__) + '[' + numberTo<std::string>(__LINE__) + "] Contract violation!");
 
     int bytesReceived = 0;
     for (;;)
@@ -158,8 +193,7 @@ size_t tryReadSocket(SocketType socket, void* buffer, size_t bytesToRead) //thro
     if (bytesReceived < 0)
         THROW_LAST_SYS_ERROR_WSA("recv");
 
-    if (static_cast<size_t>(bytesReceived) > bytesToRead) //better safe than sorry
-        throw SysError(formatSystemError("recv", L"", L"Buffer overflow."));
+    ASSERT_SYSERROR(makeUnsigned(bytesReceived) <= bytesToRead); //better safe than sorry
 
     return bytesReceived; //"zero indicates end of file"
 }
@@ -168,7 +202,7 @@ size_t tryReadSocket(SocketType socket, void* buffer, size_t bytesToRead) //thro
 size_t tryWriteSocket(SocketType socket, const void* buffer, size_t bytesToWrite) //throw SysError; may return short! CONTRACT: bytesToWrite > 0
 {
     if (bytesToWrite == 0)
-        throw std::logic_error("Contract violation! " + std::string(__FILE__) + ':' + numberTo<std::string>(__LINE__));
+        throw std::logic_error(std::string(__FILE__) + '[' + numberTo<std::string>(__LINE__) + "] Contract violation!");
 
     int bytesWritten = 0;
     for (;;)
@@ -182,11 +216,12 @@ size_t tryWriteSocket(SocketType socket, const void* buffer, size_t bytesToWrite
     }
     if (bytesWritten < 0)
         THROW_LAST_SYS_ERROR_WSA("send");
-    if (bytesWritten > static_cast<int>(bytesToWrite))
-        throw SysError(formatSystemError("send", L"", L"Buffer overflow."));
+
     if (bytesWritten == 0)
         throw SysError(formatSystemError("send", L"", L"Zero bytes processed."));
 
+    ASSERT_SYSERROR(makeUnsigned(bytesWritten) <= bytesToWrite); //better safe than sorry
+
     return bytesWritten;
 }
 }
